@@ -60,15 +60,14 @@ package Mail::SpamAssassin::Plugin::AWL;
 
 use strict;
 use warnings;
-use bytes;
+# use bytes;
 use re 'taint';
 use Mail::SpamAssassin::Plugin;
 use Mail::SpamAssassin::AutoWhitelist;
 use Mail::SpamAssassin::Util qw(untaint_var);
 use Mail::SpamAssassin::Logger;
 
-use vars qw(@ISA);
-@ISA = qw(Mail::SpamAssassin::Plugin);
+our @ISA = qw(Mail::SpamAssassin::Plugin);
 
 # constructor: register the eval rule
 sub new {
@@ -109,7 +108,7 @@ for messages, depending on the long-term behavior of the particular
 correspondent.
 
 For more information about the auto-whitelist system, please look
-at the the C<Automatic Whitelist System> section of the README file.
+at the C<Automatic Whitelist System> section of the README file.
 The auto-whitelist is not intended as a general-purpose replacement
 for static whitelist entries added to your config files.
 
